@@ -1,7 +1,7 @@
 package Simulation::DiscreteEvent::Server;
 
 use Moose;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 use Moose::Util::MetaRole;
 BEGIN {
     extends 'MooseX::MethodAttributes::Inheritable';
@@ -10,7 +10,7 @@ use namespace::clean -except => ['meta'];
 
 =head1 NAME
 
-Simulation::DiscreteEvent::Server - Moose role for implementing servers
+Simulation::DiscreteEvent::Server - Moose class for implementing servers
 
 =head1 SYNOPSIS
 
@@ -28,13 +28,14 @@ Simulation::DiscreteEvent::Server - Moose role for implementing servers
 
 =head1 Description
 
-This is a Moose role that used to implement servers for L<Simulation::DiscreteEvent> models.
+This is a base class for implementing servers for L<Simulation::DiscreteEvent>
+models.
 
 =head1 SUBROUTINES/METHODS
 
 =cut
 
-has model => ( is => 'ro', isa => 'Simulation::DiscreteEvent' );
+has model => ( is => 'ro', isa => 'Simulation::DiscreteEvent', weak_ref => 1 );
 
 =head2 $self->name([$name])
 
@@ -90,45 +91,9 @@ __END__
 
 Pavel Shaydo, C<< <zwon at cpan.org> >>
 
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-simulation-discreteevent at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Simulation-DiscreteEvent>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
-
 =head1 SUPPORT
 
-You can find documentation for this module with the perldoc command.
-
-    perldoc Simulation::DiscreteEvent
-
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Simulation-DiscreteEvent>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Simulation-DiscreteEvent>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Simulation-DiscreteEvent>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Simulation-DiscreteEvent/>
-
-=back
-
-
-=head1 ACKNOWLEDGEMENTS
-
+Please see documentation for L<Simulation::DiscreteEvent>
 
 =head1 LICENSE AND COPYRIGHT
 
